Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(42)

Unified Diff: ash/common/wm/workspace/workspace_layout_manager.h

Issue 2699033002: Replace WmWindowObserver with aura::WindowObserver. (Closed)
Patch Set: Check for null images in ShelfWindowWatcher. Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/common/wm/workspace/workspace_layout_manager.h
diff --git a/ash/common/wm/workspace/workspace_layout_manager.h b/ash/common/wm/workspace/workspace_layout_manager.h
index 80cefe83320236a313830ff5a7c6ed2230f282d3..85413a71ae21927a415f794ade9b94645e45492a 100644
--- a/ash/common/wm/workspace/workspace_layout_manager.h
+++ b/ash/common/wm/workspace/workspace_layout_manager.h
@@ -14,15 +14,17 @@
#include "ash/common/wm/wm_types.h"
#include "ash/common/wm_activation_observer.h"
#include "ash/common/wm_layout_manager.h"
-#include "ash/common/wm_window_observer.h"
#include "base/macros.h"
+#include "ui/aura/window_observer.h"
#include "ui/display/display_observer.h"
#include "ui/gfx/geometry/rect.h"
#include "ui/keyboard/keyboard_controller_observer.h"
namespace ash {
+
class RootWindowController;
class WmShell;
+class WmWindow;
class WorkspaceLayoutManagerBackdropDelegate;
namespace wm {
@@ -32,7 +34,7 @@ class WMEvent;
// LayoutManager used on the window created for a workspace.
class ASH_EXPORT WorkspaceLayoutManager
: public WmLayoutManager,
- public WmWindowObserver,
+ public aura::WindowObserver,
public WmActivationObserver,
public keyboard::KeyboardControllerObserver,
public display::DisplayObserver,
@@ -58,15 +60,14 @@ class ASH_EXPORT WorkspaceLayoutManager
void SetChildBounds(WmWindow* child,
const gfx::Rect& requested_bounds) override;
- // Overriden from WmWindowObserver:
- void OnWindowTreeChanged(
- WmWindow* window,
- const WmWindowObserver::TreeChangeParams& params) override;
- void OnWindowPropertyChanged(WmWindow* window,
- WmWindowProperty property) override;
- void OnWindowStackingChanged(WmWindow* window) override;
- void OnWindowDestroying(WmWindow* window) override;
- void OnWindowBoundsChanged(WmWindow* window,
+ // Overriden from aura::WindowObserver:
+ void OnWindowHierarchyChanged(const HierarchyChangeParams& params) override;
+ void OnWindowPropertyChanged(aura::Window* window,
+ const void* key,
+ intptr_t old) override;
+ void OnWindowStackingChanged(aura::Window* window) override;
+ void OnWindowDestroying(aura::Window* window) override;
+ void OnWindowBoundsChanged(aura::Window* window,
const gfx::Rect& old_bounds,
const gfx::Rect& new_bounds) override;
« no previous file with comments | « ash/common/wm/workspace/multi_window_resize_controller.cc ('k') | ash/common/wm/workspace/workspace_layout_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698